@@ -1,6 +1,6 @@
 # Proc::Background::Win32 Windows interface to background process management.
 #
-# Copyright (C) 1998-2002 Blair Zajac.  All rights reserved.
+# Copyright (C) 1998-2005 Blair Zajac.  All rights reserved.
 
 package Proc::Background::Win32;
 
@@ -12,7 +12,7 @@ use Carp;
 
 use vars qw(@ISA $VERSION);
 @ISA     = qw(Exporter);
-$VERSION = sprintf '%d.%02d', '$Revision: 1.08 $' =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%d.%02d', '$Revision: 1.09 $' =~ /(\d+)\.(\d+)/;
 
 BEGIN {
   eval "use Win32";
@@ -146,11 +146,11 @@ This package uses the Win32::Process class to manage the objects.
 
 =head1 AUTHOR
 
-Blair Zajac <blair@orcaware.com
+Blair Zajac <blair@orcaware.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2002 Blair Zajac.  All rights reserved.  This
+Copyright (C) 1998-2005 Blair Zajac.  All rights reserved.  This
 package is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
